#
# spec file for package perl-XML-Atom
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-Atom
Name:           perl-XML-Atom
Version:        0.43
Release:        1.15
Summary:        Atom feed and API implementation
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIYAGAWA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Data::Inheritable)
BuildRequires:  perl(DateTime)
BuildRequires:  perl(DateTime::TimeZone)
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.59
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(URI)
BuildRequires:  perl(XML::LibXML) >= 2.0202
BuildRequires:  perl(XML::XPath) >= 1.20
Requires:       perl(Class::Data::Inheritable)
Requires:       perl(DateTime)
Requires:       perl(DateTime::TimeZone)
Requires:       perl(Digest::SHA)
Requires:       perl(LWP::UserAgent)
Requires:       perl(URI)
Requires:       perl(XML::LibXML) >= 2.0202
Requires:       perl(XML::XPath) >= 1.20
%{perl_requires}

%description
Atom is a syndication, API, and archiving format for weblogs and other
data. _XML::Atom_ implements the feed format as well as a client for the
API.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Tue May  4 2021 Tina Müller <tina.mueller@suse.com>
- Remove patches d2c045a8ca0d0ca147b04bc9e7c70b27db8cc4e1.patch and
  fix-tests.patch (issues fixed upstream)
* Thu Apr 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.43
  see /usr/share/doc/packages/perl-XML-Atom/Changes
  0.43  2021-04-28 13:39:09 PDT
  * Use Digest::SHA instead of Digest::SHA1 #13
  * Fix tests when no '.' is in @INC #14
  * Enable expand_entities for XML::LibXML 2.0202 #20
  * Bump dependency for XML::LibXML
  * Bump dependency for XML::XPath and removed unnecessary override #23
* Mon Feb 10 2020 Stephan Kulow <coolo@suse.com>
- add fix-tests.patch to fix build with latest libxml::xml
* Thu Nov  8 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix Build: Add d2c045a8ca0d0ca147b04bc9e7c70b27db8cc4e1.patch
* Tue May 16 2017 coolo@suse.com
- updated to 0.42
  see /usr/share/doc/packages/perl-XML-Atom/Changes
  0.42  2017-05-12 14:33:09 JST
  * Doc fixes
  * Remove encoding pragma to support latest version of perl
    https://rt.cpan.org/Ticket/Display.html?id=115101
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.41
  see /usr/share/doc/packages/perl-XML-Atom/Changes
  0.41  2011.09.26
  * Added a dependency to DateTime::TimeZone (leto)
  0.40  2011.09.18
  * Fixed tests for Windows (wchristian)
  * use all upper case UTF-8 (tsgit)
  0.39  2011.06.20
  * Disabled external entities and network to avoid possible security flaw (yannk)
  0.38  2011.05.22
  * Fixed a bug where content with newlines wasn't encoded in perl >= 5.12 (emasaka)
    https://rt.cpan.org/Public/Bug/Display.html?id=61637
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.41
  see /usr/share/doc/packages/perl-XML-Atom/Changes
  0.41  2011.09.26
  * Added a dependency to DateTime::TimeZone (leto)
  0.40  2011.09.18
  * Fixed tests for Windows (wchristian)
  * use all upper case UTF-8 (tsgit)
  0.39  2011.06.20
  * Disabled external entities and network to avoid possible security flaw (yannk)
  0.38  2011.05.22
  * Fixed a bug where content with newlines wasn't encoded in perl >= 5.12 (emasaka)
    https://rt.cpan.org/Public/Bug/Display.html?id=61637
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- update to 0.37:
  * fixed accessors for source elements
- changes from 0.36:
  * fixed various dependency issues RT #23538, #34481, #52519, #41058
- changes from 0.34:
  * fixed $entry->source support
- changes from 0.33:
  * client: Send WSSE auth header only when username is set
- changes from 0.32:
  * added base and lang to Entry and Feed object. Fixed xml:base attributes
- changes from 0.31:
  * update Content-Type in XML::Atom::Client when the entity's version >= 1.0
- changes from 0.30:
  * hopefully fix a bug where xml:base returns an empty string
    e.g. http://www.nntp.perl.org/group/perl.cpan.testers/2008/11/msg2595696.html
- changes from 0.29:
  * skips Unicode tests since it doesn't pass with some libxml versions (and it's not actually a bug)
* Tue Jul 22 2008 guru@unixtech.be
- new package (0.28)
